.. _combining:

**********************************************
Combining streams (`baseband_tasks.combining`)
**********************************************

`~baseband_tasks.combining` contains tasks to combine multiple streams,
e.g., in preparation for correlation.  The combining can be done
using a user-defined function or with pre-defined implementations for
concatenation and stacking.

.. _combining_api:

Reference/API
=============

.. automodapi:: baseband_tasks.combining
   :no-inherited-members:
